@@ -1,4 +1,4 @@
-#' Installs D3 and D3plus
+#' Installs D3 and D3Plus
 #' @export
 #' @return Copies a folder named \code{d3plus} to the working directory and it contains the \code{js} files and icons to make the visualizations
 #' @importFrom utils unzip
@@ -7,7 +7,7 @@
 #' @keywords functions
 
 install_d3plus <- function() {
-  file.copy(from=system.file("extdata", "d3plus.zip", package = "oec"), to=getwd())
-  unzip("d3plus.zip")
-  file.remove("d3plus.zip")
+  file.copy(from=system.file("extdata", "d3plus-2.0.zip", package = "oec"), to=getwd())
+  unzip("d3plus-2.0.zip")
+  file.remove("d3plus-2.0.zip")
 }
